@@ -39,6 +39,7 @@ use Net::HTTP;
 use HTTP::Status qw(:constants);
 use Number::Format qw(:subs);
 use FileHandle;
+use IO::Socket::SSL qw( SSL_VERIFY_NONE );
 use strict;
 use warnings;
 
@@ -50,7 +51,7 @@ our @EXPORT_OK=qw(bool true false string Int i4 i8 double datetime
 our %EXPORT_TAGS=(all=>\@EXPORT_OK);
 our $PACKAGE_PREFIX = __PACKAGE__;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head2 prompt
 
@@ -101,7 +102,7 @@ Create a new instance of a Xen class.
 
 sub xen {Xen::API->new(@_)}
 
-=head2 new($uri, $user, $password)
+=head2 new($uri, $user, $password, $no_ssl_verify)
 
 New Xen instance. 
 
@@ -112,6 +113,7 @@ sub new {
   my $uri = shift or return;
   my $user = shift || 'root';
   my $password = shift;
+  my $no_ssl_verify = shift;
 
   my $self = {};
   bless $self, $class;
@@ -119,7 +121,17 @@ sub new {
   $uri = "http://$uri" if !URI->new($uri)->scheme;
   $self->{host} = URI->new($uri)->host;
   $self->{uri} = $uri;
-  $self->{xen} = RPC::XML::Client->new($self->{uri});
+
+  $self->{xen} = RPC::XML::Client->new($self->{uri},
+        $no_ssl_verify ? (
+          useragent => [
+            ssl_opts => {
+              verify_hostname => 0,
+              SSL_verify_mode => SSL_VERIFY_NONE,
+            },
+          ],
+        ) : ()
+  );
 
   # set up autoload packages for Xen API.
   my %seen;
